Waybackend

Struct Waybackend 

pub struct Waybackend {
    pub wire_msg_builder: MessageBuilder,
    pub wayland_fd: OwnedFd,
}
This struct holds the message builder and the wayland file descriptor

To create this struct, use the connect() function.

Fields

wire_msg_builder: MessageBuilder

the message builder incrementally builds up wire messages

wayland_fd: OwnedFd

the wayland file descriptor. You can pass this to poll to poll events

Implementations

Source

impl Waybackend

pub fn flush(&mut self) -> Result<()>