pub struct Waybackend {
pub wire_msg_builder: MessageBuilder,
pub wayland_fd: OwnedFd,
}Expand description
This struct holds the message builder and the wayland file descriptor
To create this struct, use the connect() function.
Fields
wire_msg_builder: MessageBuilderthe message builder incrementally builds up wire messages
wayland_fd: OwnedFdthe wayland file descriptor. You can pass this to poll to poll events
Implementations